networks 🔬
This is the official repository for the GenGa: A GWCNA + Co-expression networks analysis tool for gene expression analysis.

A library for the co-expression network analysis used on the project "Spatiotemporal patterns of gene expression associated with mating stimuli in the brain of female guppies"

How to use ☑️
All functions are contained within the "functions.py"
A simple example made with a subset of the paper data can be found in the notebook "genga.ipynb"
Credits 🥇
Created by B.Sc. Andrés Santiago Martínez Hernandez

Feel free to contact me for any doubts regarding usage! 📫 as.martinez@uniandes.edu.co

Advisors: PhD Natasha Bloch and PhD Felipe Giraldo